Installation — stevedore 0.7 documentation

### Navigation

- index
- next |
- previous |
- stevedore 0.7 documentation »

# Installation

## Python Versions

stevedore is tested under Python 2.7 and 3.2.

## Basic Installation

stevedore should be installed into the same site-packages area where the application and extensions are installed (either a virtualenv or the global site-packages). You may need administrative privileges to do that. The easiest way to install it is using pip:

    $ pip install stevedore

or:

    $ sudo pip install stevedore

## Download

stevedore releases are hosted on PyPI and can be downloaded from: http://pypi.python.org/pypi/stevedore

## Source Code

The source is hosted on github: https://github.com/dreamhost/stevedore

## Reporting Bugs

Please report bugs through the github project: https://github.com/dreamhost/stevedore/issues

### Navigation

- index
- next |
- previous |
- stevedore 0.7 documentation »